@@ -84,6 +84,9 @@ pref("calendar.week.start", 0);
 pref("calendar.weeks.inview", 4);
 pref("calendar.previousweeks.inview", 0);
 
+// Show week number in minimonth and multiweek/month views
+pref("calendar.view-minimonth.showWeekNumber", true);
+
 // Default days off
 pref("calendar.week.d0sundaysoff", true);
 pref("calendar.week.d1mondaysoff", false);
@@ -132,7 +135,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/4.4");
+pref("calendar.useragent.extra", "Lightning/4.5");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -142,9 +145,9 @@ pref("calendar.view.useSystemColors", false);
 pref("calendar.filter.maxiterations", 50);
 
 // Backend to use. false: libical, true: ical.js
-//@line 148 "/usr/obj/ports/seamonkey-2.39/seamonkey-2.39/calendar/lightning/content/lightning.js"
+//@line 151 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 150 "/usr/obj/ports/seamonkey-2.39/seamonkey-2.39/calendar/lightning/content/lightning.js"
+//@line 153 "/usr/obj/ports/seamonkey-2.40/seamonkey-2.40/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
